#
# spec file for package icinga2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define revision 1

# make sure that _rundir is working on older systems
%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif

%define _libexecdir %{_prefix}/lib/
%define plugindir %{_libdir}/nagios/plugins

%if "%{_vendor}" == "redhat"
%define apachename httpd
%define apacheconfdir %{_sysconfdir}/httpd/conf.d
%define apacheuser apache
%define apachegroup apache

%if 0%{?el5}%{?el6}%{?amzn}
%define use_systemd 0
%define use_selinux 0
%if %(uname -m) != "x86_64"
%define march_flag -march=i686
%endif
%else
# fedora and el>=7
%define use_systemd 1
%define use_selinux 1
%if 0%{?fedora} >= 24
# for installing limits.conf on systemd >= 228
%define configure_systemd_limits 1
%else
%define configure_systemd_limits 0
%endif
%endif
%endif

%if "%{_vendor}" == "suse"
%define plugindir %{_libexecdir}/nagios/plugins
%define apachename apache2
%define apacheconfdir  %{_sysconfdir}/apache2/conf.d
%define apacheuser wwwrun
%define apachegroup www
%if 0%{?suse_version} >= 1310
%define use_systemd 1
%if 0%{?sle_version} >= 120200 || 0%{?suse_version} > 1320
# for installing limits.conf on systemd >= 228
%define configure_systemd_limits 1
%else
%define configure_systemd_limits 0
%endif
%else
%define use_systemd 0
%endif
%endif

%define icinga_user icinga
%define icinga_group icinga
%define icingacmd_group icingacmd

%define logmsg logger -t %{name}/rpm

Summary:        Network monitoring application
License:        GPL-2.0-or-later
Group:          System/Monitoring
Name:           icinga2
Version:        2.8.4
Release:        lp150.1.1
Url:            https://www.icinga.com/
Source:         https://github.com/Icinga/%{name}/archive/v%{version}.tar.gz

Source1:        icinga2-rpmlintrc

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       %{name}-bin = %{version}-%{release}

%description
Meta package for Icinga 2 Core, DB IDO and Web.

%package bin
Summary:        Icinga 2 binaries and libraries
Group:          System/Monitoring

%if "%{_vendor}" == "suse"
Provides:       monitoring_daemon
Recommends:     monitoring-plugins
%if 0%{?suse_version} >= 1310
BuildRequires:  libyajl-devel
%endif
%endif
BuildRequires:  libedit-devel
BuildRequires:  ncurses-devel
%if "%{_vendor}" == "suse" && 0%{?suse_version} < 1210
BuildRequires:  gcc48-c++
BuildRequires:  libopenssl1-devel
BuildRequires:  libstdc++48-devel
%else
%if "%{_vendor}" == "redhat" && (0%{?el5} || 0%{?rhel} == 5 || "%{?dist}" == ".el5" || 0%{?el6} || 0%{?rhel} == 6 || "%{?dist}" == ".el6")
# Requires devtoolset-2 scl
BuildRequires:  devtoolset-2-binutils
BuildRequires:  devtoolset-2-gcc-c++
BuildRequires:  devtoolset-2-libstdc++-devel
%define scl_enable scl enable devtoolset-2 --
%else
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
%endif
BuildRequires:  openssl-devel
%endif
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  flex >= 2.5.35
BuildRequires:  make

%if 0%{?build_icinga_org} && "%{_vendor}" == "redhat" && (0%{?el5} || 0%{?rhel} == 5 || "%{?dist}" == ".el5" || 0%{?el6} || 0%{?rhel} == 6 || "%{?dist}" == ".el6")
# el5 and el6 require packages.icinga.com
BuildRequires:  boost153-devel
%else
%if 0%{?build_icinga_org} && "%{_vendor}" == "suse" && 0%{?suse_version} < 1310
# sles 11 sp3 requires packages.icinga.com
BuildRequires:  boost153-devel
%else
%if "%{_vendor}" == "suse" && 0%{?suse_version} > 1320
BuildRequires:  libboost_program_options-devel >= 1.48
BuildRequires:  libboost_regex-devel >= 1.48
BuildRequires:  libboost_system-devel >= 1.48
BuildRequires:  libboost_thread-devel >= 1.48
%else
%if (0%{?el5} || 0%{?rhel} == 5 || "%{?dist}" == ".el5" || 0%{?el6} || 0%{?rhel} == 6 || "%{?dist}" == ".el6")
# Requires EPEL repository
BuildRequires:  boost148-devel >= 1.48
%else
BuildRequires:  boost-devel >= 1.48
%endif
%endif
%endif
%endif

%if 0%{?use_systemd}
BuildRequires:  systemd-devel
Requires:       systemd
%endif

Requires:       %{name}-libs = %{version}-%{release}

%description bin
Icinga 2 is a general-purpose network monitoring application.
This subpackage provides the binaries for Icinga 2 Core.

%package common
Summary:        Common Icinga 2 configuration
Group:          System/Monitoring
%if (0%{?amzn} || 0%{?fedora} || 0%{?rhel})
Requires(pre):  shadow-utils
Requires(post): shadow-utils
%endif
BuildRequires:  logrotate
%if "%{_vendor}" == "suse"
PreReq:         permissions
Provides:       group(%{icinga_group})
Provides:       group(%{icingacmd_group})
Provides:       user(%{icinga_user})
Requires(pre):  shadow
Requires(post): shadow
# Coreutils is added because of autoyast problems reported
Requires(pre):  coreutils
Requires(post): coreutils
%if 0%{?suse_version} >= 1200
BuildRequires:  monitoring-plugins-common
Requires:       monitoring-plugins-common
%else
Recommends:     monitoring-plugins-common
%endif
Recommends:     logrotate
%endif

%description common
This subpackage provides common directories, and the UID and GUID definitions
among Icinga 2 related packages.


%package doc
Summary:        Documentation for Icinga 2
Group:          Documentation/Other

%description doc
This subpackage provides documentation for Icinga 2.


%package libs
Summary:        Libraries for Icinga 2
Group:          System/Libraries
Requires:       %{name}-common = %{version}-%{release}

%description libs
This subpackage provides the internal libraries for the daemon.


%package ido-mysql
Summary:        IDO MySQL database backend for Icinga 2
Group:          System/Monitoring
%if "%{_vendor}" == "suse"
BuildRequires:  libmysqlclient-devel
%if 0%{?suse_version} >= 1310
BuildRequires:  mysql-devel
%endif

%else
BuildRequires:  mysql-devel
%endif #suse

Requires:       %{name} = %{version}-%{release}

%description ido-mysql
Icinga 2 IDO mysql database backend. Compatible with Icinga 1.x
IDOUtils schema >= 1.12


%package ido-pgsql
Summary:        IDO PostgreSQL database backend for Icinga 2
Group:          System/Monitoring
%if "%{_vendor}" == "suse" && 0%{?suse_version} < 1210
BuildRequires:  postgresql-devel >= 8.4
%else
BuildRequires:  postgresql-devel
%endif
Requires:       %{name} = %{version}-%{release}

%description ido-pgsql
Icinga 2 IDO PostgreSQL database backend. Compatible with Icinga 1.x
IDOUtils schema >= 1.12

%if 0%{?use_selinux}
%global selinux_variants mls targeted
%global selinux_modulename %{name}

%package selinux
Summary:        SELinux policy module supporting icinga2
Group:          System/Base
BuildRequires:  checkpolicy
BuildRequires:  hardlink
BuildRequires:  selinux-policy-devel
Requires:       %{name} = %{version}-%{release}
Requires(post):   policycoreutils-python
Requires(postun): policycoreutils-python

%description selinux
SELinux policy module supporting icinga2.
%endif

%package -n vim-icinga2
Summary:        Vim syntax highlighting for icinga2
Group:          Productivity/Text/Editors
%if "%{_vendor}" == "suse"
BuildRequires:  vim
Requires:       vim
%else
Requires:       vim-filesystem
%endif

%description -n vim-icinga2
Provides Vim syntax highlighting for icinga2.


%package -n nano-icinga2
Summary:        Nano syntax highlighting for icinga2
Group:          Productivity/Text/Editors
Requires:       nano

%description -n nano-icinga2
Provides Nano syntax highlighting for icinga2.

%prep
%setup -q -n %{name}-%{version}
# use absolute shebang instead of env on SUSE distributions
%if "%{_vendor}" == "suse"
find . -type f -name '*.sh' -exec sed -i -e 's|\/usr\/bin\/env bash|\/bin\/bash|g' {} \;
%endif

%build
CMAKE_OPTS="-DCMAKE_INSTALL_PREFIX=/usr \
         -DCMAKE_INSTALL_SYSCONFDIR=/etc \
         -DCMAKE_INSTALL_LOCALSTATEDIR=/var \
         -DCMAKE_BUILD_TYPE=RelWithDebInfo \
         -DICINGA2_LTO_BUILD=ON \
         -DCMAKE_VERBOSE_MAKEFILE=ON \
         -DBoost_NO_BOOST_CMAKE=ON \
         -DICINGA2_PLUGINDIR=%{plugindir} \
         -DICINGA2_RUNDIR=%{_rundir} \
         -DICINGA2_USER=%{icinga_user} \
         -DICINGA2_GROUP=%{icinga_group} \
         -DICINGA2_COMMAND_GROUP=%{icingacmd_group}"
%if 0%{?fedora}
CMAKE_OPTS="$CMAKE_OPTS -DICINGA2_WITH_STUDIO=true"
%endif
%if "%{_vendor}" == "redhat"
%if 0%{?el5} || 0%{?rhel} == 5 || "%{?dist}" == ".el5" || 0%{?el6} || 0%{?rhel} == 6 || "%{?dist}" == ".el6"
%if 0%{?build_icinga_org}
# Boost_VERSION 1.41.0 vs 101400 - disable build tests
# details in https://dev.icinga.com/issues/5033
CMAKE_OPTS="$CMAKE_OPTS -DBOOST_LIBRARYDIR=%{_libdir}/boost153 \
 -DBOOST_INCLUDEDIR=/usr/include/boost153 \
 -DBoost_ADDITIONAL_VERSIONS='1.53;1.53.0'"
%else
CMAKE_OPTS="$CMAKE_OPTS -DBOOST_LIBRARYDIR=%{_libdir}/boost148 \
 -DBOOST_INCLUDEDIR=/usr/include/boost148 \
 -DBoost_ADDITIONAL_VERSIONS='1.48;1.48.0'"
%endif
CMAKE_OPTS="$CMAKE_OPTS \
 -DBoost_NO_SYSTEM_PATHS=TRUE \
 -DBUILD_TESTING=FALSE \
 -DBoost_NO_BOOST_CMAKE=TRUE"
%endif
%endif

%if "%{_vendor}" == "suse" && 0%{?suse_version} < 1310
CMAKE_OPTS="$CMAKE_OPTS -DBOOST_LIBRARYDIR=%{_libdir}/boost153 \
 -DBOOST_INCLUDEDIR=/usr/include/boost153 \
 -DBoost_ADDITIONAL_VERSIONS='1.53;1.53.0' \
 -DBoost_NO_SYSTEM_PATHS=TRUE \
 -DBUILD_TESTING=FALSE \
 -DBoost_NO_BOOST_CMAKE=TRUE"
%endif

%if 0%{?use_systemd}
CMAKE_OPTS="$CMAKE_OPTS -DUSE_SYSTEMD=ON"
%endif

%if "%{_vendor}" == "suse" && 0%{?suse_version} < 1210
# from package gcc48-c++
export CC=gcc-4.8
export CXX=g++-4.8
%endif

%{?scl_enable} cmake $CMAKE_OPTS -DCMAKE_C_FLAGS:STRING="%{optflags} %{?march_flag}" -DCMAKE_CXX_FLAGS:STRING="%{optflags} %{?march_flag}" -DICINGA2_BUILD_HOST_NAME:STRING=hostname .

make %{?_smp_mflags}

%if 0%{?use_selinux}
cd tools/selinux
for selinuxvariant in %{selinux_variants}
do
  make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile
  mv %{selinux_modulename}.pp %{selinux_modulename}.pp.${selinuxvariant}
  make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile clean
done
cd -
%endif

%install
make install \
	DESTDIR="%{buildroot}"

# install custom limits.conf for systemd
%if 0%{?configure_systemd_limits}
# for > 2.8 or > 2.7.2
%if "%{_vendor}" == "suse"
install -D -m 0644 etc/initsystem/icinga2.service.limits.conf %{buildroot}/%{_unitdir}/%{name}.service.d/limits.conf
%else
install -D -m 0644 etc/initsystem/icinga2.service.limits.conf %{buildroot}/etc/systemd/system/%{name}.service.d/limits.conf
%endif
%endif

# remove features-enabled symlinks
rm -f %{buildroot}/%{_sysconfdir}/%{name}/features-enabled/*.conf

# enable suse rc links
%if "%{_vendor}" == "suse"
%if 0%{?use_systemd}
  ln -sf /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}
%else
  ln -sf ../../%{_initrddir}/%{name} "%{buildroot}%{_sbindir}/rc%{name}"
%endif
mkdir -p "%{buildroot}%{_fillupdir}/"
mv "%{buildroot}%{_sysconfdir}/sysconfig/%{name}" "%{buildroot}%{_fillupdir}/sysconfig.%{name}"
%endif

%if 0%{?use_selinux}
cd tools/selinux
for selinuxvariant in %{selinux_variants}
do
  install -d %{buildroot}%{_datadir}/selinux/${selinuxvariant}
  install -p -m 644 %{selinux_modulename}.pp.${selinuxvariant} \
    %{buildroot}%{_datadir}/selinux/${selinuxvariant}/%{selinux_modulename}.pp
done
cd -

# TODO: Fix build problems on Icinga, see https://github.com/Icinga/puppet-icinga_build/issues/11
#/usr/sbin/hardlink -cv %%{buildroot}%%{_datadir}/selinux
%endif

%if "%{_vendor}" == "suse"
install -D -m 0644 tools/syntax/vim/syntax/%{name}.vim %{buildroot}%{_datadir}/vim/site/syntax/%{name}.vim
install -D -m 0644 tools/syntax/vim/ftdetect/%{name}.vim %{buildroot}%{_datadir}/vim/site/ftdetect/%{name}.vim
%else
install -D -m 0644 tools/syntax/vim/syntax/%{name}.vim %{buildroot}%{_datadir}/vim/vimfiles/syntax/%{name}.vim
install -D -m 0644 tools/syntax/vim/ftdetect/%{name}.vim %{buildroot}%{_datadir}/vim/vimfiles/ftdetect/%{name}.vim
%endif

install -D -m 0644 tools/syntax/nano/%{name}.nanorc %{buildroot}%{_datadir}/nano/%{name}.nanorc

%pre common
getent group %{icinga_group} >/dev/null || %{_sbindir}/groupadd -r %{icinga_group}
getent group %{icingacmd_group} >/dev/null || %{_sbindir}/groupadd -r %{icingacmd_group}
getent passwd %{icinga_user} >/dev/null || %{_sbindir}/useradd -c "icinga" -s /sbin/nologin -r -d %{_localstatedir}/spool/%{name} -G %{icingacmd_group} -g %{icinga_group} %{icinga_user}

%if "%{_vendor}" == "suse"
%if 0%{?use_systemd}
  %service_add_pre %{name}.service
%endif

%verifyscript common
%verify_permissions -e %{_rundir}/%{name}/cmd
%endif

%post common
# suse
%if "%{_vendor}" == "suse"
%if 0%{?suse_version} >= 1310
%set_permissions %{_rundir}/%{name}/cmd
%endif

%if 0%{?use_systemd}
%fillup_only  %{name}
%service_add_post %{name}.service
%else
%fillup_and_insserv %{name}
%endif

if [ ${1:-0} -eq 1 ]
then
	# initial installation, enable default features
	for feature in checker notification mainlog; do
		ln -sf ../features-available/${feature}.conf %{_sysconfdir}/%{name}/features-enabled/${feature}.conf
	done
fi

exit 0

%else
# rhel

%if 0%{?use_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

if [ ${1:-0} -eq 1 ]
then
	# initial installation, enable default features
	for feature in checker notification mainlog; do
		ln -sf ../features-available/${feature}.conf %{_sysconfdir}/%{name}/features-enabled/${feature}.conf
	done
fi

exit 0

%endif
# suse/rhel

%postun common
# suse
%if "%{_vendor}" == "suse"
%if 0%{?use_systemd}
  %service_del_postun %{name}.service
%else
  %restart_on_update %{name}
  %insserv_cleanup
%endif

%else
# rhel

%if 0%{?use_systemd}
%systemd_postun_with_restart %{name}.service
%else
if [ "$1" -ge  "1" ]; then
	/sbin/service %{name} condrestart >/dev/null 2>&1 || :
fi
%endif

%endif
# suse / rhel

if [ "$1" = "0" ]; then
	# deinstallation of the package - remove enabled features
	rm -rf %{_sysconfdir}/%{name}/features-enabled
fi

exit 0

%preun common
# suse
%if "%{_vendor}" == "suse"

%if 0%{?use_systemd}
  %service_del_preun %{name}.service
%else
  %stop_on_removal %{name}
%endif

exit 0

%else
# rhel

%if 0%{?use_systemd}
%systemd_preun %{name}.service
%else
if [ "$1" = "0" ]; then
	/sbin/service %{name} stop > /dev/null 2>&1 || :
	/sbin/chkconfig --del %{name} || :
fi
%endif

exit 0

%endif
# suse / rhel

%post ido-mysql
if [ ${1:-0} -eq 1 ]
then
	# initial installation, enable ido-mysql feature
	ln -sf ../features-available/ido-mysql.conf %{_sysconfdir}/%{name}/features-enabled/ido-mysql.conf
fi

exit 0

%postun ido-mysql
if [ "$1" = "0" ]; then
	# deinstallation of the package - remove feature
	rm -f %{_sysconfdir}/%{name}/features-enabled/ido-mysql.conf
fi

exit 0

%post ido-pgsql
if [ ${1:-0} -eq 1 ]
then
	# initial installation, enable ido-pgsql feature
	ln -sf ../features-available/ido-pgsql.conf %{_sysconfdir}/%{name}/features-enabled/ido-pgsql.conf
fi

exit 0

%postun ido-pgsql
if [ "$1" = "0" ]; then
	# deinstallation of the package - remove feature
	rm -f %{_sysconfdir}/%{name}/features-enabled/ido-pgsql.conf
fi

exit 0

%if 0%{?use_selinux}
%post selinux
for selinuxvariant in %{selinux_variants}
do
  /usr/sbin/semodule -s ${selinuxvariant} -i \
    %{_datadir}/selinux/${selinuxvariant}/%{selinux_modulename}.pp &> /dev/null || :
done
/sbin/fixfiles -R icinga2-bin restore &> /dev/null || :
/sbin/fixfiles -R icinga2-common restore &> /dev/null || :
/sbin/semanage port -a -t icinga2_port_t -p tcp 5665 &> /dev/null || :

%postun selinux
if [ $1 -eq 0 ] ; then
  /sbin/semanage port -d -t icinga2_port_t -p tcp 5665 &> /dev/null || :
  for selinuxvariant in %{selinux_variants}
  do
     /usr/sbin/semodule -s ${selinuxvariant} -r %{selinux_modulename} &> /dev/null || :
  done
  /sbin/fixfiles -R icinga2-bin restore &> /dev/null || :
  /sbin/fixfiles -R icinga2-common restore &> /dev/null || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc COPYING

%files bin
%defattr(-,root,root,-)
%doc COPYING COPYING.Exceptions README.md NEWS AUTHORS CHANGELOG.md
%{_sbindir}/%{name}
%dir %{_libdir}/%{name}/sbin
%{_libdir}/%{name}/sbin/%{name}
%{plugindir}/check_nscp_api
%{_datadir}/%{name}
%exclude %{_datadir}/%{name}/include
%{_mandir}/man8/%{name}.8.gz

%files libs
%defattr(-,root,root,-)
%doc COPYING COPYING.Exceptions README.md NEWS AUTHORS CHANGELOG.md
%exclude %{_libdir}/%{name}/libdb_ido_mysql*
%exclude %{_libdir}/%{name}/libdb_ido_pgsql*
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.so*

%files common
%defattr(-,root,root,-)
%doc COPYING COPYING.Exceptions README.md NEWS AUTHORS CHANGELOG.md tools/syntax
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_sysconfdir}/bash_completion.d/%{name}
%if 0%{?use_systemd}
%attr(644,root,root) %{_unitdir}/%{name}.service
%if 0%{?configure_systemd_limits}
%if "%{_vendor}" == "suse"
%dir %{_unitdir}/%{name}.service.d
%{_unitdir}/%{name}.service.d/limits.conf
%else
%dir /etc/systemd/system/%{name}.service.d
%attr(644,root,root) %config(noreplace) /etc/systemd/system/%{name}.service.d/limits.conf
%endif
%endif
%else
%attr(755,root,root) %config(noreplace) %{_sysconfdir}/init.d/%{name}
%endif
%if "%{_vendor}" == "suse"
%{_sbindir}/rc%{name}
%{_fillupdir}/sysconfig.%{name}
%else
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%endif
%attr(0750,root,%{icinga_group}) %dir %{_sysconfdir}/%{name}
%attr(0750,%{icinga_user},%{icinga_group}) %dir %{_sysconfdir}/%{name}/conf.d
%attr(0750,%{icinga_user},%{icinga_group}) %dir %{_sysconfdir}/%{name}/features-available
%exclude %{_sysconfdir}/%{name}/features-available/ido-*.conf
%attr(0750,%{icinga_user},%{icinga_group}) %dir %{_sysconfdir}/%{name}/features-enabled
%attr(0750,%{icinga_user},%{icinga_group}) %dir %{_sysconfdir}/%{name}/scripts
%attr(0750,%{icinga_user},%{icinga_group}) %dir %{_sysconfdir}/%{name}/zones.d
%config(noreplace) %attr(0640,%{icinga_user},%{icinga_group}) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %attr(0640,%{icinga_user},%{icinga_group}) %{_sysconfdir}/%{name}/constants.conf
%config(noreplace) %attr(0640,%{icinga_user},%{icinga_group}) %{_sysconfdir}/%{name}/zones.conf
%config(noreplace) %attr(0640,%{icinga_user},%{icinga_group}) %{_sysconfdir}/%{name}/conf.d/*.conf
%config(noreplace) %attr(0640,%{icinga_user},%{icinga_group}) %{_sysconfdir}/%{name}/features-available/*.conf
%config(noreplace) %attr(0640,%{icinga_user},%{icinga_group}) %{_sysconfdir}/%{name}/zones.d/*
%config(noreplace) %{_sysconfdir}/%{name}/scripts/*
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/prepare-dirs
%{_libexecdir}/%{name}/safe-reload
%attr(0750,%{icinga_user},%{icingacmd_group}) %{_localstatedir}/cache/%{name}
%attr(0750,%{icinga_user},%{icingacmd_group}) %dir %{_localstatedir}/log/%{name}
%attr(0750,%{icinga_user},%{icinga_group}) %dir %{_localstatedir}/log/%{name}/crash
%attr(0750,%{icinga_user},%{icingacmd_group}) %dir %{_localstatedir}/log/%{name}/compat
%attr(0750,%{icinga_user},%{icingacmd_group}) %dir %{_localstatedir}/log/%{name}/compat/archives
%attr(0750,%{icinga_user},%{icinga_group}) %{_localstatedir}/lib/%{name}
%attr(0750,%{icinga_user},%{icingacmd_group}) %ghost %dir %{_rundir}/%{name}
%attr(2750,%{icinga_user},%{icingacmd_group}) %ghost %{_rundir}/%{name}/cmd
%attr(0750,%{icinga_user},%{icinga_group}) %dir %{_localstatedir}/spool/%{name}
%attr(0770,%{icinga_user},%{icinga_group}) %dir %{_localstatedir}/spool/%{name}/perfdata
%attr(0750,%{icinga_user},%{icinga_group}) %dir %{_localstatedir}/spool/%{name}/tmp
%attr(0750,%{icinga_user},%{icinga_group}) %dir %{_datadir}/%{name}/include
%{_datadir}/%{name}/include/*

%files doc
%defattr(-,root,root,-)
%{_datadir}/doc/%{name}
%docdir %{_datadir}/doc/%{name}

%files ido-mysql
%defattr(-,root,root,-)
%doc COPYING COPYING.Exceptions README.md NEWS AUTHORS CHANGELOG.md
%config(noreplace) %attr(0640,%{icinga_user},%{icinga_group}) %{_sysconfdir}/%{name}/features-available/ido-mysql.conf
%{_libdir}/%{name}/libdb_ido_mysql*
%{_datadir}/icinga2-ido-mysql

%files ido-pgsql
%defattr(-,root,root,-)
%doc COPYING COPYING.Exceptions README.md NEWS AUTHORS CHANGELOG.md
%config(noreplace) %attr(0640,%{icinga_user},%{icinga_group}) %{_sysconfdir}/%{name}/features-available/ido-pgsql.conf
%{_libdir}/%{name}/libdb_ido_pgsql*
%{_datadir}/icinga2-ido-pgsql

%if 0%{?use_selinux}
%files selinux
%defattr(-,root,root,0755)
%doc tools/selinux/*
%{_datadir}/selinux/*/%{selinux_modulename}.pp
%endif

%files -n vim-icinga2
%defattr(-,root,root,-)
%if "%{_vendor}" == "suse"
%{_datadir}/vim/site/syntax/%{name}.vim
%{_datadir}/vim/site/ftdetect/%{name}.vim
%else
%{_datadir}/vim/vimfiles/syntax/%{name}.vim
%{_datadir}/vim/vimfiles/ftdetect/%{name}.vim
%endif

%files -n nano-icinga2
%defattr(-,root,root,-)
%if "%{_vendor}" == "suse"
%dir %{_datadir}/nano
%endif
%{_datadir}/nano/%{name}.nanorc

%changelog
* Fri Apr 27 2018 thardeck@suse.com
- update to version 2.8.4
  * fix plugins crash when run from icinga2-2.8.3
  * Fix InfluxDB backslash escaping
  * Fix Elasticsearch crash on invalid performance data
  * Sysconfig file settings are taken into account
  * Support multiple parameters for check_nscp_api
  * Documentation enhancements and fixes
- remove obsolete patch icinga2-2.8.2-boost.patch
* Tue Apr 17 2018 thardeck@suse.com
- fix bsc#1089808 by back porting the upstream patch icinga2-2.8.2-boost.patch
* Mon Apr  9 2018 ro@suse.de
- fix _fillupdir usage
* Fri Mar 23 2018 thardeck@suse.com
- update to version 2.8.2 (fixes CVE-2017-16933 - bsc#1086676, CVE-2018-6532 - bsc#1086672, CVE-2018-6533 - bsc#1086673,
  CVE-2018-6534 - bsc#1086674, CVE-2018-6535 - bsc#1086675, CVE-2018-6536)
  * [#5715](https://github.com/icinga/icinga2/issues/5715) (API, PR): Hash API password and comparison
  * [#6153](https://github.com/icinga/icinga2/issues/6153) (API, PR): Improve error handling for empty packages in /v1/config/packages
  * [#6147](https://github.com/icinga/icinga2/issues/6147) (PR): Fix incorrect argument type for JsonRpc::SendMessage
  * [#6146](https://github.com/icinga/icinga2/issues/6146) (PR): Ensure that SetCorked\(\) works properly
  * [#6134](https://github.com/icinga/icinga2/issues/6134) (PR): Fix incorrect HTTP content length limits
  * [#6133](https://github.com/icinga/icinga2/issues/6133) (PR): Limit the number of HTTP/JSON-RPC requests we read in parallel
  * [#6132](https://github.com/icinga/icinga2/issues/6132) (PR): Fix HTTP parser crash/hang
  * [#6129](https://github.com/icinga/icinga2/issues/6129): api/packages not created by prepare-dir/daemon
  * [#5995](https://github.com/icinga/icinga2/issues/5995) (InfluxDB, PR): Fix InfluxDB requests
  * [#5991](https://github.com/icinga/icinga2/issues/5991): Partial privilege escalation via PID file manipulation
  * [#5987](https://github.com/icinga/icinga2/issues/5987) (Elasticsearch, InfluxDB, Metrics): InfluxDBWriter and ElasticsearchWriter stop writing to HTTP API
  * [#5943](https://github.com/icinga/icinga2/issues/5943) (PR): Fix incorrect ::Start call
  * [#5793](https://github.com/icinga/icinga2/issues/5793): CVE-2017-16933: root privilege escalation via prepare-dirs \(init script and systemd service file\)
  * [#5760](https://github.com/icinga/icinga2/issues/5760) (Crash, PR): Fix incorrect socket handling for the HTTP client
  * [#6148](https://github.com/icinga/icinga2/issues/6148) (PR): Fix ApiUser unit test
  * [#6135](https://github.com/icinga/icinga2/issues/6135) (API, Cluster, PR): Limit JSON RPC message size
  * [#6115](https://github.com/icinga/icinga2/issues/6115) (PR): Fix incorrect size of request limits
  * [#6114](https://github.com/icinga/icinga2/issues/6114) (PR): Fix typo in prepare-dirs
  * [#6104](https://github.com/icinga/icinga2/issues/6104) (PR): Fix nullptr dereferences
  * [#6103](https://github.com/icinga/icinga2/issues/6103) (PR): HTTP Security fixes
  * [#5982](https://github.com/icinga/icinga2/issues/5982) (Packages, PR): SELinux: Allows icinga2\_t to send sigkill to all domains it transitions to
  * [#5916](https://github.com/icinga/icinga2/issues/5916) (Packages): Unable to kill process group after check timeout if SElinux is enabled
  * [#5850](https://github.com/icinga/icinga2/issues/5850) (Installation, PR): init script security fixes
  * [#5764](https://github.com/icinga/icinga2/issues/5764) (InfluxDB, code-quality, PR): Improve InfluxdbWriter performance
  * [#5759](https://github.com/icinga/icinga2/issues/5759) (code-quality, PR): Make default getters and setters non-virtual
- install limits.conf to systemd directory instead of etc
* Mon Mar 12 2018 bwiedemann@suse.com
- override ICINGA2_BUILD_HOST_NAME to make builds reproducible (boo#1084909)
* Mon Feb 19 2018 thardeck@suse.com
- incorporate spec changes from upstream
* Sun Feb  4 2018 ecsos@opensuse.org
- fix build error for 15.0, Tumbleweed and Factory
* Wed Jan 17 2018 thardeck@suse.com
- update to upstream version 2.8.1
  * [#5856](https://github.com/Icinga/icinga2/issues/5856) (PR): Implement AppLocal deployment support for UCRT
  * [#5986](https://github.com/Icinga/icinga2/issues/5986) (DB IDO, PR): Fix wrong schema constraint for fresh 2.8.0 installations
  * [#5947](https://github.com/Icinga/icinga2/issues/5947) (DB IDO): Duplicate entry constraint violations in 2.8
  * [#5907](https://github.com/Icinga/icinga2/issues/5907) (PR): Windows plugin check\_swap build fix
  * [#5808](https://github.com/Icinga/icinga2/issues/5808) (Crash, PR): Fix missing variable name which can lead to segfaults
  * [#5807](https://github.com/Icinga/icinga2/issues/5807) (Crash): icinga v2.8.0 crashes frequently with "segmentation fault" on Debian 8.9
  * [#5804](https://github.com/Icinga/icinga2/issues/5804) (Log, PR): Silence UpdateRepository message errors
  * [#5776](https://github.com/Icinga/icinga2/issues/5776) (Cluster, Log): 2.8.0: warning/JsonRpcConnection: Call to non-existent function 'event::UpdateRepository'
  * [#5746](https://github.com/Icinga/icinga2/issues/5746) (Livestatus, PR): livestatus: custom variables return empty arrays instead of strings
  * [#5716](https://github.com/Icinga/icinga2/issues/5716) (Livestatus, PR): add bogus zero reply in livestatus when aggregate and non matching filter
  * [#5626](https://github.com/Icinga/icinga2/issues/5626) (Livestatus, help wanted): Empty result set with non-matching filters in Livestatus stats query
  * [#5785](https://github.com/Icinga/icinga2/issues/5785) (ITL, PR): ITL: Drop ssl\_sni default setting
  * [#5775](https://github.com/Icinga/icinga2/issues/5775) (ITL): Default usage of ssl\_sni in check\_tcp
* Wed Dec 13 2017 thardeck@suse.com
- add logrotate as BuildRequires for the setup to recognize the version and
  enable the su usage accordingly
* Tue Dec 12 2017 thardeck@suse.com
- fix libboost devel dependencies for Tumbleweed
* Mon Nov 27 2017 thardeck@suse.com
- add user and group provides
* Mon Nov 27 2017 thardeck@suse.com
- remove icinga2.service.limits.conf from package source and use the one from
  the tarball instead
* Fri Nov 17 2017 thardeck@suse.com
- update to upstream version 2.8.0
  * Certificate path changed to /var/lib/icinga2/certs - check the upgrading docs!
  * DB IDO 2.8.0 schema upgrade
  * Cluster/Clients: Forward certificate signing requests over multiple levels
  * Cluster/Clients: Support on-demand signing next to ticket based certificate request signing
  * New flapping detection algorithm
  * Add ElasticsearchWriter feature with HTTP proxy support
  * Add CORS support for the REST API
  * Deprecate `flapping_threshold` config option
  * Remove client configuration mode "bottom up"
  * Remove classicui meta configuration package
  * Remove deprecated `enable_legacy_mode` in Graphite feature
  * Spec file was moved to https://github.com/icinga/icinga-packaging
  * ITL CheckCommand definition updates
  * Documentation updates
* Tue Nov 14 2017 jengelh@inai.de
- Documentation should not hard-require the program, as it is
  technically "usable" without it.
- Rectify RPM groups, fix odd grammar in descriptions.
- Remove redundant %%clean section.
* Mon Nov 13 2017 thardeck@suse.com
- add icinga2.service.limits.conf on Tumbleweed too
* Fri Nov 10 2017 thardeck@suse.com
- update to upstream version 2.7.2
  * Fixed invalid attribute names in the systemd unit file
  * Improve documentation and systemd config on TaskMax
  * Fixed incorrect unique constraint for IDO DB
  * Moved spec file to the icinga-packaging Git repository
  * Documentation updates
* Thu Sep 21 2017 thardeck@suse.com
- update to upstream version 2.7.1
  * Fixes and upgrade documentation for notificatication scripts introduced in 2.7.0
  * InfluxdbWriter attribute socket_timeout introduced in 2.7.0 was deprecated (will be removed in 2.8.0). Details in #5469 and #5460
  * Livestatus bygroup table stats fixes for NagVis
  * DB IDO: Fixes for downtime/comment history queries not correctly updating the end time
  * check_nscp_api allows white spaces in arguments
* Tue Sep  5 2017 thardeck@suse.com
- adapt spec to latest upstream changes
* Fri Aug 25 2017 thardeck@suse.com
- fix SLES and Factory building issues
* Thu Aug 24 2017 thardeck@suse.com
- take upstream icinga2.spec as base again (fixes bnc#1055032)
- fix wrong position of classicui sed statement
- fix faulty systemd cleanup statement on suse systems
* Thu Aug  3 2017 ecsos@opensuse.org
- update to upstream version 2.7.0
  Too many changes to write.
  See https://github.com/Icinga/icinga2/milestone/59?closed=1 or
  in changelog.
* Wed Apr  5 2017 adamradovits12@hotmail.com
- update to upstream version 2.6.3
  * This is a bugfix release which addresses a number of bugs we've found since
    2.6.2 was released. It also contains a number of improvements for the Icinga
    documentation.
* Sat Mar 18 2017 aj@ajaissle.de
- Fix typo in %%postun's use_systemd conditional
* Mon Feb 13 2017 thardeck@suse.com
- update to upstream version 2.6.2
  * This is a bugfix release which addresses a crash that can occur when removing configuration files for objects which have been deleted via the API.
* Wed Feb  1 2017 thardeck@suse.com
- update to upstream version 2.6.1
  * This release addresses a number of bugs we have identified in version 2.6.0.
  * The documentation changes
  * reflect our recent move to GitHub.
- Increase libstdc++-devel requirement to 48
* Tue Dec 13 2016 thardeck@suse.com
- update to upstream version 2.6.0
  * Client/Satellite setup
  * The "bottom up" client configuration mode has been deprecated. Check [#13255](https://dev.icinga.org/issues/13255) for additional details and migration.
  * Linux/Unix daemon
  * Ensure that Icinga 2 does not leak file descriptors to executed commands.
  * There are 2 processes started instead of previously just one process.
  * Cluster and API
  * Provide location information for objects and templates in the API
  * Improve log message for ignored config updates
  * Fix cluster resync problem with API created objects (hosts, downtimes, etc.)
  * Fix that API-created objects in a global zone are not synced to child endpoints
  * Notifications
  * Several bugfixes for downtime, custom and flapping notifications
  * New ITL CheckCommands: logstash, glusterfs, iostats
  * Package builds require a compiler which supports C++11 features (gcc-c++ >= 4.7, clang++)
  * DB IDO
  * Schema upgrade required (2.6.0.sql)
  * This update fixes timestamp columns required by Icinga Web 2 and might take a while. Please ensure to schedule a maintenance task for your database upgrade.
* Tue Aug 30 2016 thardeck@suse.com
- update to upstream version 2.5.4
  * InfluxdbWriter feature
  * API
  * New endpoints: /v1/variables and /v1/templates (GET requests), /v1/action/generate-ticket (POST request)
  * State/type filters for notifications/users are now string values (PUT, POST, GET requests)
  * Configuration
  * TimePeriod excludes/includes attributes
  * DateTime object for formatting time strings
  * New prototype methods: Array#filter, Array#unique, Array#map, Array#reduce
  * icinga2.conf now includes plugins-contrib, manubulon, windows-plugins, nscp by default (ITL CheckCommand definitions)
  * Performance improvements (config compiler and validation)
  * CLI
  * 'icinga2 object list' formats state/type filters as string values
  * Compiled config files are now visible with "notice" debug level (hidden by default)
  * CA serial file now uses a hash value (HA cluster w/ 2 CA directories)
  * Cluster
  * There is a known issue with >2 endpoints inside a zone. Icinga 2 will now log a warning.
  * Support for accepted ciphers and minimum TLS version
  * Connection and error logging has been improved.
  * DB IDO
  * Schema upgrade required (2.5.0.sql)
  * Incremental config dump (performance boost)
  * `categories` attribute is now an array. Previous method is deprecated and to be removed.
  * DbCatLog is not enabled by default anymore.
  * SSL support for MySQL
  * New packages
  * vim-icinga2 for syntax highlighting
  * libicinga2 (Debian), icinga2-libs (RPM) for Icinga Studio packages
* Sat Jun 25 2016 ecsos@opensuse.org
- update to upstream version 2.4.10
  * Bugfixes
  * Bug 11812 (Checker): Checker component doesn't execute any checks for command_endpoint
- change from 2.4.9
  * Bugfixes
  * Bug 11801 (Perfdata): Error: Function call 'rename' for file '/var/spool/icinga2/tmp/service-perfdata' failed with error code 2, 'No such file or directory'
  * Bug 11804 (Configuration): Segfault when trying to start 2.4.8
  * Bug 11807 (Compat): Command Pipe thread 100%% CPU Usage
- changes from 2.4.8
  * Changes
  * Bugfixes
  * Support for limiting the maximum number of concurrent checks (new configuration option)
  * HA-aware features now wait for connected cluster nodes in the same zone (e.g. DB IDO)
  * The 'icinga' check now alerts on failed reloads
  * Feature
  * Feature 8137 (Checker): Maximum concurrent service checks
  * Feature 9236 (Perfdata): PerfdataWriter: Better failure handling for file renames across file systems
  * Feature 9997 (libmethods): "icinga" check should have state WARNING when the last reload failed
  * Feature 10581 (ITL): Provide icingacli in the ITL
  * Feature 11556 (libbase): Add support for subjectAltName in SSL certificates
  * Feature 11651 (CLI): Implement SNI support for the CLI commands
  * Feature 11720 (ITL): 'disk' CheckCommand: Exclude 'cgroup' and 'tracefs' by default
  * Feature 11748 (Cluster): Remove unused cluster commands
  * Feature 11765 (Cluster): Only activate HARunOnce objects once there's a cluster connection
  * Feature 11768 (Documentation): Add the category to the generated changelog
  * Bugfixes
  * Bug 9989 (Configuration): Service apply without name possible
  * Bug 10426 (libicinga): Icinga crashes with a segfault on receiving a lot of check results for nonexisting hosts/services
  * Bug 10717 (Configuration): Comments and downtimes of deleted checkable objects are not deleted
  * Bug 11046 (Cluster): Icinga2 agent gets stuck after disconnect and won't relay messages
  * Bug 11112 (Compat): Empty author/text attribute for comment/downtimes external commands causing crash
  * Bug 11147 (libicinga): "day -X" time specifications are parsed incorrectly
  * Bug 11158 (libicinga): Crash with empty ScheduledDowntime 'ranges' attribute
  * Bug 11374 (API): Icinga2 API: deleting service with cascade=1 does not delete dependant notification
  * Bug 11390 (Compat): Command pipe overloaded: Can't send external Icinga command to the local command file
  * Bug 11396 (API): inconsistent API /v1/objects/* response for PUT requests
  * Bug 11589 (libicinga): notification sent out during flexible downtime
  * Bug 11645 (Documentation): Incorrect chapter headings for Object#to_string and Object#type
  * Bug 11646 (Configuration): Wrong log severity causes segfault
  * Bug 11686 (API): Icinga Crash with the workflow Create_Host-> Downtime for the Host ->  Delete Downtime -> Remove Host
  * Bug 11711 (libicinga): Expired downtimes are not removed
  * Bug 11714 (libbase): Crash in UnameHelper
  * Bug 11742 (Documentation): Missing documentation for event commands w/ execution bridge
  * Bug 11757 (API): API: Missing error handling for invalid JSON request body
  * Bug 11767 (DB IDO): Ensure that program status updates are immediately updated in DB IDO
  * Bug 11779 (API): Incorrect variable names for joined fields in filters
  >>>>>>> ./icinga2.changes.r55
* Wed Apr 27 2016 ecsos@opensuse.org
- update to upstream version 2.4.7
  * Bugfixes
  * Bug 11639: Crash in IdoMysqlConnection::ExecuteMultipleQueries
- changes from 2.4.6
  * Feature
  * Feature 11638: Update RELEASE.md
  * Bugfixes
  * Bug 11628: Docs: Zone attribute 'endpoints' is an array
  * Bug 11634: Icinga 2 fails to build on Ubuntu Xenial
  * Bug 11635: Failed assertion in IdoPgsqlConnection::FieldToEscapedString
* Wed Apr 20 2016 thardeck@suse.com
- update to upstream version 2.4.5
  * New configuration attribute for hosts and services: check_timeout (overrides the CheckCommand's timeout when set)
  * ITL updates
  * Lots of bugfixes
* Wed Mar 16 2016 thardeck@suse.com
- update to upstream version 2.4.4
  * Allow to enforce specific SSL versions using the http check command
  * Add "query" option to check_postgres command.
  * Lots and lots of various other bugfixes
- gcc48-c++ is now required
* Wed Feb 24 2016 thardeck@suse.com
- update to upstream version 2.4.2
  * ITL
    Additional arguments for check_disk
    Fix incorrect path for the check_hpasm plugin
    New command: check_iostat
    Fix incorrect variable names for the check_impi plugin
  * Cluster
    Improve cluster performance
    Fix connection handling problems (multiple connections for the same endpoint)
  * Performance improvements for the DB IDO modules
  * Lots and lots of various other bugfixes
  * Documentation updates
* Thu Nov 26 2015 thardeck@suse.com
-  update to upstream version 2.4.1
  * ITL
  * Add running_kernel_use_sudo option for the running_kernel check
  * Configuration
  * Add global constants: `PlatformName`. `PlatformVersion`, `PlatformKernel` and `PlatformKernelVersion`
  * CLI
  * Use NodeName and ZoneName constants for 'node setup' and 'node wizard'
* Mon Nov 16 2015 thardeck@suse.com
- update to upstream version 2.4.0
  * API
  * RESTful API with basic auth or client certificates
  * Filters, types, permissions
  * configuration package management
  * query/create/modify/delete config objects at runtime
  * status queries for global stats
  * actions (e.g. acknowledge all service problems)
  * event streams
  * ITL and Plugin Check Command definitions
  * The 'running_kernel' check command was moved to the plugins-contrib section. You have to update your config to include 'plugins-contrib'
  * Configuration
  * The global constants Enable* and Vars have been removed. Use the IcingaApplication object attributes instead.
  * Features
  * New Graphite tree. Please check the documentation how enable the legacy schema.
  * IcingaStatusWriter feature has been deprecated and will be removed in future versions.
  * Modified attributes are not exposed as bit mask to external interfaces anymore (api related changes). External commands like CHANGE_*_MODATTR have been removed.
* Tue Oct 20 2015 thardeck@suse.com
- update to upstream version 2.3.11
  * Function for performing CIDR matches: cidr_match()
  * New methods: String#reverse and Array#reverse
  * New ITL command definitions: nwc_health, hpasm, squid, pgsql
  * Additional arguments for ITL command definitions: by_ssh, dig, pop, spop, imap, simap
  * Documentation updates
  * Various bugfixes
* Mon Sep  7 2015 thardeck@suse.com
- add icinga2-rpmlintrc as source to spec file
* Mon Sep  7 2015 thardeck@suse.com
- update to upstream version 2.3.10
  * Use the command_endpoint name as check_source value if defined
  * Various other bugfixes
* Mon Aug 31 2015 thardeck@suse.com
- update to upstream version 2.3.9
  * Fix that the first SOFT state is recognized as second SOFT state
  * Implemented reload functionality for Windows
  * New ITL check commands
  * Documentation updates
  * Various other bugfixes
* Tue Jul 21 2015 thardeck@suse.com
- update to upstream version 2.3.8
  * Bugfixes
* Wed Jul 15 2015 thardeck@suse.com
- update to upstream version 2.3.7
  * Bugfixes
  * Feature 9610: Enhance troubleshooting ssl errors & cluster replay log
* Wed Jul  8 2015 thardeck@suse.com
- update to upstream version 2.3.6
  * Require openssl1 on sles11sp3 from Security Module repository
  * Bug in SLES 11's OpenSSL version 0.9.8j preventing verification of generated certificates.
  * Re-create these certificates with 2.3.6 linking against openssl1 (cli command or CSR auto-signing).
  * ITL: Add ldap, ntp_peer, mongodb and elasticsearch CheckCommand definitions
  * Bugfixes
* Thu Jun 18 2015 thardeck@suse.com
- update to upstream version 2.3.5
  * NSClient++ is now bundled with the Windows setup wizard and can optionally be installed
  * Windows Wizard: "include <nscp>" is set by default
  * Windows Wizard: Add update mode
  * Plugins: Add check_perfmon plugin for Windows
  * ITL: Add CheckCommand objects for Windows plugins ("include <windows-plugins>")
  * ITL: Add CheckCommand definitions for "mongodb", "iftraffic", "disk_smb"
  * ITL: Add arguments to CheckCommands "dns", "ftp", "tcp", "nscp"
* Wed Apr 22 2015 thardeck@suse.com
- update to upstream version 2.3.4
  * Bugfixes
  * ITL: Check commands for various databases
  * Improve validation messages for time periods
  * Update max_check_attempts in generic-{host,service} templates
  * Update logrotate configuration
* Mon Mar 30 2015 thardeck@suse.com
- update to upstream version 2.3.3
  * Feature 8685: Show state/type filter names in notice/debug log
  * Feature 8686: Update documentation for "apply for" rules
  * Feature 8693: New function: parse_performance_data
  * Feature 8740: Add "access objects at runtime" examples to advanced section
  * Feature 8761: Include more details in --version
  * Feature 8816: Add "random" CheckCommand for test and demo purposes
  * Feature 8827: Move release info in INSTALL.md into a separate file
  * Bug 8660: Update syntax highlighting for 2.3 features
  * Bug 8677: Re-order the object types in alphabetical order
  * Bug 8724: Missing config validator for command arguments 'set_if'
  * Bug 8734: startup.log broken when the DB schema needs an update
  * Bug 8736: Don't update custom vars for each status update
  * Bug 8748: Don't ignore extraneous arguments for functions
  * Bug 8749: Build warnings with CMake 3.1.3
  * Bug 8750: Flex version check does not reject unsupported versions
  * Bug 8753: Fix a typo in the documentation of ICINGA2_WITH_MYSQL and ICINGA2_WITH_PGSQL
  * Bug 8755: Fix VIM syntax highlighting for comments
  * Bug 8757: Add missing keywords in the syntax highlighting files
  * Bug 8762: Plugin "check_http" is missing in Windows environments
  * Bug 8763: Typo in doc library-reference
  * Bug 8764: Revamp migration documentation
  * Bug 8765: Explain processing logic/order of apply rules with for loops
  * Bug 8766: Remove prompt to create a TicketSalt from the wizard
  * Bug 8767: Typo and invalid example in the runtime macro documentation
  * Bug 8769: Improve error message for invalid field access
  * Bug 8770: object Notification + apply Service fails with error "...refers to service which doesn't exist"
  * Bug 8771: Correct HA documentation
  * Bug 8829: Figure out why command validators are not triggered
  * Bug 8834: Return doesn't work inside loops
  * Bug 8844: Segmentation fault when executing "icinga2 pki new-cert"
  * Bug 8862: wrong 'dns_lookup' custom attribute default in command-plugins.conf
  * Bug 8866: Fix incorrect perfdata templates in the documentation
  * Bug 8869: Array in command arguments doesn't work
  * Bug 8721: Log message for cli commands breaks the init script
* Thu Mar 12 2015 thardeck@suse.com
- update to upstream version 2.3.1
  * Feature 8659: Implement String#contains
  * Bug 8540: Kill signal sent only to check process, not whole process group
  * Bug 8657: Missing program name in 'icinga2 --version'
  * Bug 8658: Fix check_disk thresholds: make sure partitions are the last arguments
  * Bug 8672: Api heartbeat message response time problem
  * Bug 8673: Fix check_disk default thresholds and document the change of unit
  * Bug 8679: Config validation fail because of unexpected new-line
  * Bug 8680: Update documentation for DB IDO HA Run-Once
  * Bug 8683: Make sure that the /var/log/icinga2/crash directory exists
  * Bug 8684: Fix formatting for the GDB stacktrace
  * Bug 8687: Crash in Dependency::Stop
  * Bug 8691: Debian packages do not create /var/log/icinga2/crash
* Tue Mar 10 2015 thardeck@suse.com
- update to upstream version 2.3.0
  * Feature 3446: Add troubleshooting collect cli command
  * Feature 6109: Don't spawn threads for network connections
  * Feature 6570: Disallow side-effect-free r-value expressions in expression lists
  * Feature 6697: Plugin Check Commands: add check_vmware_esx
  * Feature 6857: Run CheckCommands with C locale (workaround for comma vs dot and plugin api bug)
  * Feature 6858: Add some more PNP details
  * Feature 6868: Disable flapping detection by default
  * Feature 6923: IDO should fill program_end_time on a clean shutdown
  * Feature 7136: extended Manubulon SNMP Check Plugin Command
  * Feature 7209: ITL: Interfacetable
  * Feature 7256: Add OpenTSDB Writer
  * Feature 7292: ITL: Check_Mem.pl
  * Feature 7294: ITL: ESXi-Hardware
  * Feature 7326: Add parent soft states option to Dependency object configuration
  * Feature 7361: Livestatus: Add GroupBy tables: hostsbygroup, servicesbygroup, servicesbyhostgroup
  * Feature 7545: Please add labels in SNMP checks
  * Feature 7564: Access object runtime attributes in custom vars & command arguments
  * Feature 7610: Variable from for loop not usable in assign statement
  * Feature 7700: Evaluate apply/object rules when the parent objects are created
  * Feature 7702: Add an option that hides CLI commands
  * Feature 7704: ConfigCompiler::HandleInclude* should return an AST node
  * Feature 7706: ConfigCompiler::Compile* should return an AST node
  * Feature 7748: Redesign how stack frames work for scripts
  * [...]
* Thu Feb  5 2015 thardeck@suse.com
- update to upstream version 2.2.4
  * Bug #6943: Configured recurring downtimes not applied on saturdays
  * Bug #7660: livestatus / nsca / etc submits are ignored during reload
  * Bug #7685: kUn-Bashify mail-{host,service}-notification.sh
  * Bug #8128: Icinga 2.2.2 build fails on SLES11SP3 because of changed boost dependency
  * Bug #8131: vfork() hangs on OS X
  * Bug #8162: Satellite doesn't use manually supplied 'local zone name'
  * Bug #8192: Feature statusdata shows wrong host notification options
  * Bug #8201: Update Icinga Web 2 uri to /icingaweb2
  * Bug #8214: Fix YAJL detection on Debian squeeze
  * Bug #8222: inconsistent URL http(s)://www.icinga.org
  * Bug #8223: Typos in readme file for windows plugins
  * Bug #8245: check_ssmtp command does NOT support mail_from
  * Bug #8256: Restart fails after deleting a Host
  * Bug #8288: Crash in DbConnection::ProgramStatusHandler
  * Bug #8295: Restart of Icinga hangs
  * Bug #8299: Scheduling downtime for host and all services only schedules services
  * Bug #8311: Segfault in Checkable::AddNotification
  * Bug #8321: enable_event_handlers attribute is missing in status.dat
  * Bug #8368: Output in "node wizard" is confusing
* Thu Jan 29 2015 thardeck@suse.com
- update to upstream version 2.2.3
  * Bug #8063: Volatile checks trigger invalid notifications on OK->OK state changes
  * Bug #8125: Incorrect ticket shouldn't cause "node wizard" to terminate
  * Bug #8126: Icinga 2.2.2 doesn't build on i586 SUSE distributions
  * Bug #8143: Windows plugin check_service.exe can't find service NTDS
  * Bug #8144: Arguments without values are not used on plugin exec
  * Bug #8147: check_interval must be greater than 0 error on update-config
  * Bug #8152: DB IDO query queue limit reached on reload
  * Bug #8171: Typo in example of StatusDataWriter
  * Bug #8178: Icinga 2.2.2 segfaults on FreeBSD
  * Bug #8181: icinga2 node update config shows hex instead of human readable names
  * Bug #8182: Segfault on update-config old empty config
* Thu Dec 18 2014 thardeck@suse.com
- removed Use-Icinga-1.x-Apache-conf.patch (fixed upstream)
- update to upstream version 2.2.2
  * Bug #7045: icinga2 init-script doesn't validate configuration on reload action
  * Bug #7064: Missing host downtimes/comments in Livestatus
  * Bug #7301: Docs: Better explaination of dependency state filters
  * Bug #7314: double macros in command arguments seems to lead to exception
  * Bug #7511: Feature `compatlog' should flush output buffer on every new line
  * Bug #7518: update-config fails to create hosts
  * Bug #7591: CPU usage at 100%% when check_interval = 0 in host object definition
  * Bug #7618: Repository does not support services which have a slash in their name
  * Bug #7683: If a parent host goes down, the child host isn't marked as unrechable in the db ido
  * Bug #7707: "node wizard" shouldn't crash when SaveCert fails
  * Bug #7745: Cluster heartbeats need to be more aggressive
  * Bug #7769: The unit tests still crash sometimes
  * Bug #7863: execute checks locally if command_endpoint == local endpoint
  * Bug #7878: Segfault on issuing node update-config
  * Bug #7882: Improve error reporting when libmysqlclient or libpq are missing
  * Bug #7891: CLI `icinga2 node update-config` doesn't sync configs from remote clients as expected
  * Bug #7913: /usr/lib/icinga2 is not owned by a package
  * Bug #7914: SUSE packages %%set_permissions post statement wasn't moved to common
  * Bug #7917: update_config not updating configuration
  * Bug #7920: Test Classic UI config file with Apache 2.4
  * Bug #7929: Apache 2.2 fails with new apache conf
  * [...]
* Tue Dec  2 2014 thardeck@suse.com
- added Use-Icinga-1.x-Apache-conf.patch to fix apache configuration
* Mon Dec  1 2014 thardeck@suse.com
- removed icinga2-make-apache-conf-flexible.conf (fixed upstream)
- imported upstream spec
- update to upstream version 2.2.1
  * Feature #6709: Support for arrays in macros
  * Feature #7463: Update spec file to use yajl-devel
  * Feature #7739: The classicui Apache conf doesn't support Apache 2.4
  * Feature #7747: Increase default timeout for NRPE checks
  * Feature #7867: Document how arrays in macros work
  * Bug #7173: service icinga2 status gives wrong information when run as unprivileged user
  * Bug #7602: livestatus large amount of submitting unix socket command results in broken pipes
  * Bug #7613: icinga2 checkconfig should fail if group given for command files does not exist
  * Bug #7671: object and template with the same name generate duplicate object error
  * Bug #7708: Built-in commands shouldn't be run on the master instance in remote command execution mode
  * Bug #7725: Windows wizard uses incorrect CLI command
  * Bug #7726: Windows wizard is missing --zone argument
  * Bug #7730: Restart Icinga - Error Restoring program state from file '/var/lib/icinga2/icinga2.state'
  * Bug #7735: 2.2.0 has out-of-date icinga2 man page
  * Bug #7738: Systemd rpm scripts are run in wrong package
  * Bug #7740: /usr/sbin/icinga-prepare-dirs conflicts in the bin and common package
  * Bug #7741: Icinga 2.2 misses the build requirement libyajl-devel for SUSE distributions
  * Bug #7743: Icinga2 node add failed with unhandled exception
  * Bug #7754: Incorrect error message for localhost
  * [...]
* Thu Nov 20 2014 thardeck@suse.com
- imported upstream spec (`python-icinga2` package dropped)
- added icinga2-make-apache-conf-flexible.conf to make the Apache conf work with Apache 2.4
- added new build requirement libyajl-devel
- update to upstream version 2.2.0
  * `python-icinga2` package dropped in favor of integrated cli commands #7245
  * DB IDO schema update to version `1.12.0`
  * [GelfWriter](#gelfwriter): Logging check results, state changes, notifications to GELF (graylog2, logstash) #7619
  * Agent/Client/Node framework #7249
  * Windows plugins for the client/agent parts #7242 #7243
  * `icinga2 feature {enable,disable}` replaces `icinga2-{enable,disable}-feature` script  #7250
  * `icinga2 object list` replaces `icinga2-list-objects` script  #7251
  * `icinga2 pki` replaces` icinga2-build-{ca,key}` scripts  #7247
  * `icinga2 repository` manages `/etc/icinga2/repository.d` which must be included in `icinga2.conf` #7255
  * `icinga2 node` cli command provides node (master, satellite, agent) setup (wizard) and management functionality #7248
  * `icinga2 daemon` for existing daemon arguments (`-c`, `-C`). Removed `-u` and `-g` parameters in favor of [init.conf](#init-conf).
  * bash auto-completion & terminal colors #7396
  * Former `localhost` example host is now defined in [hosts.conf](#hosts-conf) #7594
  * All example services moved into advanced apply rules in [services.conf](#services-conf)
  * Updated downtimes configuration example in [downtimes.conf](#downtimes-conf) #7472
  * Updated notification apply example in [notifications.conf](#notifications-conf) #7594
  * [...]
* Tue Sep 16 2014 thardeck@suse.com
- update to upstream version 2.1.1
  * Bug #6147: Link libcJSON against libm
  * Bug #6696: make test fails on openbsd
  * Bug #6841: Too many queued messages
  * Bug #6862: SSL_read errors during restart
  * Bug #6981: SSL errors with interleaved SSL_read/write
  * Bug #7029: icinga2.spec: files-attr-not-set for python-icinga2 package
  * Bug #7032: "Error parsing performance data" in spite of "enable_perfdata = false"
  * Bug #7036: Remove validator for the Script type
  * Bug #7037: icinga2-list-objects doesn't work with Python 3
  * Bug #7038: Fix rpmlint errors
  * Bug #7042: icinga2-list-objects complains about Umlauts and stops output
  * Bug #7044: icinga2 init-script terminates with exit code 0 if $DAEMON is not in place or not executable
  * Bug #7047: service icinga2 status - prints cat error if the service is stopped
  * Bug #7058: Exit code is not initialized for some failed checks
  * Bug #7065: pipe2 returns ENOSYS on GNU Hurd and Debian kfreebsd
  * Bug #7072: GraphiteWriter should ignore empty perfdata value
  * Bug #7080: Missing differentiation between service and systemctl
  * Bug #7096: new SSL Errors with too many queued messages
  * Bug #7115: Build fails on Haiku
  * Bug #7123: Manubulon-Plugin conf Filename wrong
  * Bug #7139: GNUInstallDirs.cmake outdated
  * [...]
* Fri Aug 29 2014 thardeck@suse.com
- update to upstream version 2.1
  * DB IDO schema upgrade ([MySQL](#upgrading-mysql-db),[PostgreSQL](#upgrading-postgresql-db) required!
  * new schema version: **1.11.7**
  * RPMs install the schema files into `/usr/share/icinga2-ido*` instead of `/usr/share/doc/icinga2-ido*` #6881
  * [Information for config objects](#list-configuration-objects) using `icinga2-list-objects` script #6702
  * Add Python 2.4 as requirement #6702
  * Add search path: If `-c /etc/icinga2/icinga2.conf` is omitted, use `SysconfDir + "/icinga2/icinga2.conf"` #6874
  * Change log level for failed commands #6751
  * Notifications are load-balanced in a [High Availability cluster setup](#high-availability-notifications) #6203
  * New config attribute: `enable_ha`
  * DB IDO "run once" or "run everywhere" mode in a [High Availability cluster setup](#high-availability-db-ido) #6203 #6827
  * New config attributes: `enable_ha` and `failover_timeout`
  * RPMs use the `icingacmd` group for /var/{cache,log,run}/icinga2 #6948
  * Bug #6881: make install does not install the db-schema
  * Bug #6915: use _rundir macro for configuring the run directory
  * Bug #6916: External command pipe: Too many open files
  * Bug #6917: enforce /usr/lib as base for the cgi path on SUSE distributions
  * Bug #6942: ExternalCommandListener fails open pipe: Too many open files
  * Bug #6948: check file permissions in /var/cache/icinga2
  * Bug #6962: Commands are processed multiple times
  * [...]
* Thu Aug 14 2014 thardeck@suse.com
- remove idoutils provides statement
- replace icinga-apache-conf.patch by a sed statement
* Thu Aug  7 2014 thardeck@suse.com
- recommend monitoring-plugins
- reactivate icinga-apache-conf.patch
* Thu Aug  7 2014 thardeck@suse.com
- removed obsolete icinga2-ignore-install-doc.patch
- use updated upstream icinga2.spec as base
- add _rundir variable to set path for cmd file
- update to upstream version 2.0.2
  * Bug #6450: ipmi-sensors segfault due to stack size
  * Bug #6479: Notifications not always triggered
  * Bug #6501: Classic UI Debian/Ubuntu: apache 2.4 requires 'a2enmod cgi' & apacheutils installed
  * Bug #6548: Add cmake constant for PluginDir
  * Bug #6549: GraphiteWriter regularly sends empty lines
  * Bug #6550: add log message for invalid performance data
  * Bug #6589: Command pipe blocks when trying to open it more than once in parallel
  * Bug #6621: Infinite loop in TlsStream::Close
  * Bug #6627: Location of the run directory is hard coded and bound to "local_state_dir"
  * Bug #6659: RPMLint security warning - missing-call-to-setgroups-before-setuid /usr/sbin/icinga2
  * Bug #6682: Missing detailed error messages on ApiListener SSL Errors
  * Bug #6686: Event Commands are triggered in OK HARD state everytime
  * Bug #6687: Remove superfluous quotes and commas in dictionaries
  * Bug #6713: sample config: add check commands location hint (itl/plugin check commands)
  * Bug #6718: "order" attribute doesn't seem to work as expected
  * Bug #6724: TLS Connections still unstable in 2.0.1
  * Bug #6756: GraphiteWriter: Malformatted integer values
  * Bug #6765: Config validation without filename argument fails with unhandled exception
  * [...]
* Thu Jul 10 2014 thardeck@suse.com
- update to upstream version 2.0.1
  * Feature #6531: Add port option to check imap/pop/smtp and a new dig
  * Feature #6581: Add more options to snmp check
  * DB IDO - Bug #5577: PostgreSQL string escaping
  * DB IDO - Bug #6577: icinga2-ido-pgsql snapshot package missing dependecy dbconfig-common
  * Documentation - Bug #6506: Array section confusing
  * Documentation - Bug #6592: Documentation for || and && is missing
  * Documentation - Feature #6658: change docs.icinga.org/icinga2/latest to git master
  * Livestatus - Bug #6494: Thruk Panorama View cannot query Host Status
  * Livestatus - Feature #5312: OutputFormat python
  * Migration - Bug #6559: $SERVICEDESC$ isn't getting converted correctly
  * Bug #6316: application fails to start on wrong log file permissions but does not tell about it
  * Bug #6368: Deadlock in ApiListener::RelayMessage
  * Bug #6373: base64 on CentOS 5 fails to read certificate bundles
  * Bug #6388: Debian package icinga2-classicui needs versioned dependency of icinga-cgi*
  * Bug #6488: build warnings
  * Bug #6492: icinga2.state could not be opened
  * Bug #6493: Copyright problems
  * Bug #6498: icinga2 cannot be built with both systemd and init.d files
  * Bug #6510: Reminder notifications are sent on disabled services
  * [...]
* Mon Jul  7 2014 thardeck@suse.com
- restore the icinga-apache patch since upstream has a different path
- move "Provides icinga-idoutils" to the correct locations
- remove "Provides" for icinga and nagios
- added rpmlintrc to filter improper warnings
* Sat Jul  5 2014 thardeck@suse.com
- fix service user permissions
- replace apache icinga.conf patch by sed statement
* Fri Jul  4 2014 thardeck@suse.com
- reduce spec file redundancies
- run SUSE related changes only on SUSE distributions
- revert post install script regression
- make sure that icinga2 is not an empty package
* Thu Jul  3 2014 thardeck@suse.com
- initial version 2.0.0
  - icinga-www is already compatible if icinga2-classicui-config is installed but then it can't interact with Icinga 1
  - icinga-web needs manual config changes to work with icinga2 atm
